.. WaterpyBal documentation master file, created by
   sphinx-quickstart on Thu Mar 30 16:07:49 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

WaterpyBal's documentation!
======================================
An open source Python library for water balance modelling

Package information
====================

Name: WaterpyBal

version: 1.0.0

Author: Ashkan Hassanzadeh   

Email: ashkan.hassanzadeh@gmail.com

python: 3.*

License: agpl-3.0


Citation
=========



Installation
==================

pip can be used for the installation:

`pip install waterpybal`

Alternatively, download the waterpybal folder from the github repository and add it to lib folder in python path alongside other python libraries.

Jupyter Notebook
==================

There is a notebook in `WaterpyBal's github repository <https://github.com/IDAEA-EVS/waterpybal>`_ that explains an example of implementing isocompy on spatial and isotopic data


WaterpyBal Studio: Graphic User interface of WaterpyBal
=======================================================

The GUI of WaterpyBal (WaterpyBal Studio), alongside the installation guide and the user manual can be found `here <http://hdl.handle.net/10261/305226>`_


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   Home
   dataset_prep
   swr_calcs
   pet_calcs
   inf_calcs
   urban_cycle
   balance_calcs
   post_processing
   LICENSE


search
=======

* :ref:`search`